config/variadics.hpp

The config/variadics.hpp header defines a macro for determining variadic macro support. The file is automatically included when needed internally. The end-user can include it also in order to use the macro.

#### Usage

#include <boost/preprocessor/config/variadics.hpp>

#### Contents

- BOOST_PP_VARIADICS

© Copyright Edward Diener 2011

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)